##############################################################################
#
# NAME:        atp.spec
#
# FACILITY:    SAM (Service Availability Monitoring)
#
# COPYRIGHT:
#         Copyright (c) 2009, Members of the EGEE Collaboration.
#         http://www.eu-egee.org/partners/
#         Licensed under the Apache License, Version 2.0.
#         http://www.apache.org/licenses/LICENSE-2.0
#         This software is provided "as is", without warranties
#         or conditions of any kind, either express or implied.
#
# DESCRIPTION:
#
#         ATP spec file
#
# AUTHORS:     David Collados, CERN
#              Joshi Pradyumna, BARC
#
# CREATED:     23-Nov-2009
#
# NOTES:
#
# MODIFIED:
#
##############################################################################

# sitelib for noarch packages, sitearch for others (remove the unneeded one)
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

Name:           atp
Version:        1.27.19
Release:        1%{?dist}
Summary:        The Aggregated Topology Provider (ATP) contains grid topology information.
Group:          Development/Languages
License:        ASL 2.0
URL:            http://tomtools.cern.ch/confluence/display/SAMDOC
Source0:        atp-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch:      noarch
BuildRequires:  python-devel
Requires:       python-simplejson >= 2.0.3
Requires:       libyaml >= 0.1.2
Requires:       PyYAML >= 3.08
Requires:       python-ldap >= 2.2.0
Requires:       python-lxml
Requires:       python-uuid
Requires:       stomppy
Requires:       mx >= 2.0.6
#Provides:	    atp-web-1.25.3

%description
The Aggregated Topology Provider (ATP) is a database containing grid 
topology information. This means list of projects (like WLCG), grid 
infrastructures (EGEE, OSG, NDGF), sites, services, VOs and their 
groupings, downtimes and a history of these.

%prep
%setup -q

%build
%{__python} setup.py build

%install
rm -rf $RPM_BUILD_ROOT
# %{__python} setup.py install -O1 --skip-build --root $RPM_BUILD_ROOT
python setup.py install --root=$RPM_BUILD_ROOT

install -d -m 755 $RPM_BUILD_ROOT/var/log/%{name}/
#install -d -m 755 $RPM_BUILD_ROOT/%{_datadir}/%{name}

%clean
rm -rf $RPM_BUILD_ROOT

%pre
# Create nagios user
if ! /usr/bin/id nagios &>/dev/null; then
    /usr/sbin/useradd -r -m -d /var/log/nagios -s /bin/sh -c "nagios" nagios || \
        logger -t nagios/rpm "Unexpected error adding user \"nagios\". Aborting installation."
fi
if ! /usr/bin/getent group nagiocmd &>/dev/null; then
    /usr/sbin/groupadd nagiocmd &>/dev/null || \
        logger -t nagios/rpm "Unexpected error adding group \"nagiocmd\". Aborting installation."
fi

#%post
#if [ ! -d /var/lib/%{name} ]; then
#        mkdir /var/lib/%{name}
#fi
#mv %{_datadir}/doc/%{name}-%{version}/oracle_schema /var/lib/%{name}
#mv %{_datadir}/doc/%{name}-%{version}/mysql_schema /var/lib/%{name}
#mv %{_datadir}/doc/%{name}-%{version}/CHANGES /var/lib/%{name}
#mv %{_datadir}/doc/%{name}-%{version}/README /var/lib/%{name}
#mv %doc/%{name}-%{version}/LICENSE /var/lib/%{name} 

# All the DB schema files & synchronizer
%files
%defattr(-,root,root,-)
%{_bindir}/atp_synchro
%{_bindir}/check_atp_sync
%{python_sitelib}/atp_synchronizer/*
%{python_sitelib}/atp/*
%doc README LICENSE oracle_schema mysql_schema CHANGES
%config(noreplace) %{_sysconfdir}/%{name}/atp_vo_feeds_schema.xsd
%config(noreplace) %{_sysconfdir}/%{name}/atp_synchro.conf
%config(noreplace) %{_sysconfdir}/%{name}/vo_feeds.conf
%config(noreplace) %{_sysconfdir}/%{name}/roc.conf
%config(noreplace) %{_sysconfdir}/%{name}/atp_logging_files.conf
%config(noreplace) %{_sysconfdir}/%{name}/atp_logging_parameters_config.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/atp.logrotate
%config(noreplace) %attr(0640,root,nagios) %{_sysconfdir}/%{name}/atp_db.conf
%dir %{_var}/log/atp
%attr(0755,root,root) %{_sysconfdir}/init.d/atp-sync
%{_sysconfdir}/%{name}_django/requires.txt
%{_sysconfdir}/%{name}_django/atp*

%changelog
* Thu Mar 07 2014 Ivan Antoniev Dzhunov <idzhunov@cern.ch> - 1.27.19-1%{?dist}
- SAM-3345 atp: ATP fails when GOCDB is not available due to unknow config variable
* Thu Nov 07 2013 Ivan Antoniev Dzhunov <idzhunov@cern.ch> - 1.27.18-1%{?dist}
- SAM-3324 atp: SRM downtimes in GOCDB don't propagate correctly to SRMv2 endpoints
* Tue Nov 04 2013 Ivan Antoniev Dzhunov <idzhunov@cern.ch> - 1.27.17-1%{?dist}
- SAM-3313 ATP fails to synchronize site-federation link
* Tue Jul 23 2013 Ivan Antoniev Dzhunov <idzhunov@cern.ch> - 1.27.16-1%{?dist}
- SAM-3305 atp uses mockbuild user for /etc/init.d/atp-sync 
* Tue Jul 23 2013 Ivan Antoniev Dzhunov <idzhunov@cern.ch> - 1.27.15-1%{?dist}
- SAM-3311 ATP tries to contacts OIM for hepspec even if OSG=No in atp config
* Thu Jul 11 2013 Wojciech Lapka <wojciech.lapka@cern.ch> - 1.27.14-1%{?dist}
- SAM-3289 Fixed synchronization of OSG downtimes 
* Thu Jun 13 2013 Wojciech Lapka <wojciech.lapka@cern.ch> - 1.27.12-1%{?dist}
- SAM-3290 DROP of table CE_METADATA fails 
* Wed Jun 12 2013 Wojciech Lapka <wojciech.lapka@cern.ch> - 1.27.11-1%{?dist}
- SAM-3289 Synchronization of OSG downtimes failing
- SAM-3288 DROP TABLE SERVICE_TYPE
* Fri Mar 01 2013 Pedro Andrade<pedro.andrade@cern.ch> - 1.27.9-1%{?dist}
- SAM-3156 Errors not reported in atp_sync output 
* Thu Feb 28 2013 Pedro Andrade<pedro.andrade@cern.ch> - 1.27.8-1%{?dist}
- SAM-3164 ATP declares downtimes for other services shared in the endpoint
- SAM-3197 vofeeds services belonging to multiple groups for the same physical site are incorrectly updated
* Thu Feb 07 2013 Paloma Fuente <pfuentef@cern.ch> - 1.27.7-1%{?dist}
- SAM-1601 (ATP MySQL) Added CREATE_ATP_SCHEMA.sql (Redesign of the db upgrades in yaim)
* Wed Jan 30 2013 Pedro Andrade<pedro.andrade@cern.ch> - 1.27.5-1%{?dist}
- SAM-3188 samval006: atp schema version incorrect
* Tue Jan 29 2013 Pedro Andrade<pedro.andrade@cern.ch> - 1.27.4-1%{?dist}
- SAM-3185 samval005: atp still using service types
* Mon Jan 28 2013 Pedro Andrade<pedro.andrade@cern.ch> - 1.27.3-2%{?dist}
- SAM-3180 atp: fails on sam-gridmon due to missing MySQLdb
* Thu Jan 24 2013 Pedro Andrade<pedro.andrade@cern.ch> - 1.27.2-1%{?dist}
- SAM-2115 Revise service flavour synchronization
- SAM-2114 Drop service types table
- SAM-2112 Remove usage of service types
* Thu Jan 24 2013 Pedro Andrade<pedro.andrade@cern.ch> - 1.27.1-1%{?dist}
- SAM-3169 samval006: python-django-db-schema is needed by package mywlcg-atp-web-1.26.2-2.el5.noarch
- SAM-3000 atp: mysql event remove services and sites non-compatible with multiple regions
- SAM-3142 problem creating /etc/atp/vo_feeds.conf for VO which has more that one '.' in name
- SAM-3170 LHCb "All Sites" group type not created in production
- SAM-2546 atp: flapping of MPI seen by several different sites
- Created new DB model v_1_20
* Tue Dec 04 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.26.4-1%{?dist}
- SAM-3128 Invalid character in json string provided by ATP
* Fri Nov 23 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.26.3-1%{?dist}
- Added sphinx documentation structure and moved atp_synchro script into atp_synchronizer package
* Tue Nov 20 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.26.2-1%{?dist}
- SAM-3096 Update gstat-prod link
* Tue Nov 08 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.26.1-1%{?dist}
- SAM-3005 ATP: flag OSG ITB services with ISINPRODUCTION='N' and sites with INFRASTTYPE='PPS'
- SAM-2995 atp: change oim import behaviour
- SAM-3068 atp: VOMS CSRF support
- SAM-2653 ATP (1.23.7-1) sync error
* Tue Oct 16 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.25.10-1%{?dist}
- SAM-3017 atp testcase failing in samval008
* Tue Sep 21 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.25.9-1%{?dist}
- Fixed SAM-2980 Missing GOCDB URL for several services
* Tue Sep 04 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.25.8-1%{?dist}
- Fixed SAM-2941 MPI services in MyEGI
- Fixed SAM-2944 group_link is not correctly updated when vofeed is updated
- Fixed SAM-2943 get_tier function return more then one record
* Mon Aug 27 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.25.7-1%{?dist}
- Fixed SAM-2878 Nagios doesn't test services which aren't in production
- Fixed SAM-2875 ncg failure on vo sam-nagios node (grid-monitoring-config-gen-0.90.10-1)
* Tue Aug 21 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.25.6-1%{?dist}
- Fixed SAM-2845 mywlcg-atp-api: missing 500 status template
- Fixed SAM-2871 flavours that are not in the feed are not cleaned up
- Fixed SAM-2892 drop events / create events
- Added new oracle and mysql schemas for v_1_19
* Tue Jun 12 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.25.5-1%{?dist}
- Final fix SAM-2781
* Tue Jun 12 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.25.4-1%{?dist}
- Temporary fix for SAM-2781
* Tue Jun 12 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.25.1-1%{?dist}
- SAM-2738 Add service id and flavour id to vo feed PI
* Fri Jun 01 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.24.1-1%{?dist}
- SAM-2506 Add vo feed validation logs to ATP probe
- SAM-2504 Groups status when vo feed is not reachable
- SAM-2547 atp: case sensitivity issues in sitenames
* Wed Mar 28 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.23.7-1%{?dist}
- SAM-2572 atp-sync does not fetch serviceendpoint for Desktop Grid services
* Tue Mar 27 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.23.6-1%{?dist}
- SAM-2568 Problems with SITE_UPDATE procedure
* Thu Mar 22 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.23.5-1%{?dist}
- SAM-2538 get_tier function not correctly created
* Wed Mar 21 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.23.4-1%{?dist}
- SAM-2490 atp_synchro and poem_sync init.d scripts signal themselves on service stop
* Mon Mar 19 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.23.3-1%{?dist}
- SAM-2477 Modified get_tier procedure to use new tiers/sites mappings
* Sat Mar 17 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.23.2-1%{?dist}
- SAM-2477 Add Tiers/PhysicalSites association
* Fri Mar 09 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.23.1-1%{?dist}
- SAM-2398 osgdowntimeid field missing from Downtime class in atp models
- SAM-2458 Function for retrieving physical site names
- SAM-2461 ROC contacts update may fail due to not existing ROC
- SAM-2342 Add associations between ATP groups
* Tue Feb 07 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.13-2%{?dist}
- SAM-2393 FAIL: Running yaim during fresh install of samval013
* Wed Feb 01 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.12-2%{?dist}
- SAM-2259 atp-web PIs for retrieving contacts must use user authentication
* Mon Jan 30 2012 Joshi Pradyumna<pjoshi@cern.ch> - 1.22.11-2%{?dist}
- SAM-2347 Multiple region support not working as expected
* Mon Jan 30 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.11-1%{?dist}
- SAM-2358 VO feed synchronizer incorrectly marking groups as deleted
- SAM-2365 Error when synchronizing GOCDB site contacts
* Thu Jan 26 2012 Joshi Pradyumna<pjoshi@cern.ch> - 1.22.10-2%{?dist}
- SAM-2341 atp_synchro error: 1222 (different number of columns)
- SAM-2343 ATP, error reports parsing problem with GOCDB sites
* Tue Jan 24 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.9-1%{?dist}
- SAM-2337 ATP on sam-gridmon is forbidden to ncg on sam-nagios
* Mon Jan 23 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.8-1%{?dist}
- SAM-2335 mddb/atp_synchro failure on sam-nagios fresh install
* Mon Jan 23 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.7-1%{?dist}
- SAM-2259 atp-web PIs for retrieving contacts must use user authentication
* Fri Jan 20 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.6-1%{?dist}
- SAM-2323 Incorrect file permissions in atp_synchro service
* Fri Jan 20 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.5-1%{?dist}
- SAM-2311 Multiple atp_synchro may run at the same time and interfere with each other (atp-1.22.3-1)
* Thu Jan 19 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.4-1%{?dist}
- SAM-2054 Create service for cronjob org.egee.ATPSync
- SAM-2321 Incorrect GOCDB url attribute to filter per ROC
* Wed Jan 11 2012 Joshi Pradyumna<pjoshi@cern.ch> - 1.22.3-2%{?dist}
- SAM-2263 Ability to filter results on atp-web
- SAM-2295 Add service id and flavour id to atp-web
* Tue Jan 10 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.2-1%{?dist}
- Fixed problem with v_1_16 database version
* Tue Jan 10 2012 Pedro Andrade<pedro.andrade@cern.ch> - 1.22.1-1%{?dist}
- SAM-2281 On sam-nagios ATP 1.21.4-2 gives warnings (which is an error for ncg, which is fatal for yaim)
- SAM-2284 internal release 15.1 and release 16 atp db version
* Wed Dec 21 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.21.4-2%{?dist}
- SAM-2268 MySQL: Install of ATP fails on nightly validation
- SAM-2275 All MPI services are marked as deleted 
* Fri Dec 16 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.21.4-1%{?dist}
- SAM-2228 ATP function get_roc_name is returning NULL for most of deleted services
- SAM-2117 Add Service URL information required by NCG
- SAM-2249 Problem with ATP API 'vofeeds'
* Wed Dec 14 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.21.3-1%{?dist}
- SAM-2249 Problem with ATP API 'vofeeds'
* Wed Dec 07 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.21.2-1%{?dist}
- Fixed DB version from 1_14 to 1_15 in oracle and mysql
* Wed Dec 07 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.21.1-1%{?dist}
- SAM-2236 Problem parsing voms servers list and contacting invalid servers
* Sun Dec 04 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.21.0-1%{?dist}
- SAM-2118 Add Users information required by NCG and voms2htpasswd
* Tue Nov 29 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.21.0-1%{?dist}
- SAM-2215 OSG availabilities are not computed
- SAM-2204 atp_synchro sometimes exits with python trace in validateVOFeeds
* Tue Nov 29 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.21.0-1%{?dist}
- SAM-2117 Add Service URL information required by NCG
* Tue Nov 22 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.21.0-1%{?dist}
- SAM-2130 ATP returning service not defined in VO feed
* Fri Nov 18 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.21.0-1%{?dist}
- SAM-2132 ATP returning service with flags: ismonitored=N and isinproduction=N
* Wed Nov 16 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.21.0-1%{?dist}
- SAM-2187 atp_sync: Change probe implementation
* Wed Nov 09 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.21.0-1%{?dist}
- SAM-2156 atp 1.20.9 gives wrong error message text
* Thu Nov 03 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.21.0-1%{?dist}
- SAM-2111 Remove default groups for VOs not providing vo feeds
* Thu Oct 27 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.20.9-1%{?dist}
- SAM-2123 atp 1.20.8-1 mysql db upgrade error
* Tue Oct 25 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.20.8-1%{?dist}
- SAM-2094 atp sync error with atp 1.20.7 on sam-nagios
* Mon Oct 24 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.20.7-1%{?dist}
- SAM-2090 Problem upgrading mysql to atp schema 1.14
* Sun Oct 23 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.20.6-1%{?dist}
- SAM-2089 ATP log doesn't keep history of executions
* Sun Oct 23 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.20.5-1%{?dist}
- SAM-1730 Mix of local, UTC and UTC-5 in httpd/error_log
- SAM-1818 Add suport for OSG preprod services
- SAM-1463 ATP doesn't get MPI flavors for CEs that use separate LRMS
* Sun Oct 23 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.20.5-1%{?dist}
- SAM-1933 Extend GOCDB synchronizer to retrieve service flavours
- SAM-1957 Add operational tools to ATP
* Sun Oct 09 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.20.4-1%{?dist}
- SAM-2017 atp 1.20.3-1 oracle schema version wrong
- SAM-2016 mysql VO_UPDATE procedure does not work in atp-1.20.3-1
- SAM-1883 Revise delete VO Groups
- SAM-1990 Error in VO_TOPOLOGY_UPDATE procedure
- SAM-1982 Revise CIC synchronizer VOs management
* Tue Oct 05 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.20.2-1%{?dist}
- SAM-2003 Verify of CIC portal feed is valid
- SAM-1948 Add validation of BDII service endpoint to GOCDB validation
- SAM-1978 Do not map VOs with BDII if they provide VO feed
- SAM-1809 Improve VO feed validation
- SAM-1990 Error in VO_TOPOLOGY_UPDATE procedure
* Tue Sep 14 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.19.6-1%{?dist}
- SAM-1916 ATP probe always returning error state
* Tue Sep 13 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.19.5-1%{?dist}
- SAM-1909 atp_synchro error on gridmon
* Tue Sep 13 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.19.4-1%{?dist}
- SAM-1888 Error during oracle db upgrade of atp to schema 1.13
- SAM-1906 Old groups not removed from ATP when VO feed is changed
* Tue Sep 13 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.19.4-1%{?dist}
- SAM-1463 ATP doesn't get MPI flavors for CEs that use separate LRMS
- SAM-1893 All CMS groups in validation and preprod DB marked as deleted
* Tue Sep 06 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.19.3-1%{?dist}
- SAM-1823 Remove FQDN parsing - vo feeds validation
- SAM-1781 Storing of VOFeed synchronizer lastrun not enabled
- SAM-1839 config_atp: ATP VO feed configuration
- SAM-1834 Package vo feed xsd in atp
- SAM-1757 Drop unused ATP tables
- SAM-1871 Improve log messages and log level
- SAM-1808 Validation of input data in ATP synchronizers
* Tue Sep 06 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.19.3-1%{?dist}
- SAM-1785 BDII log in ATP
- SAM-1819 OSG topology synchronizer should take hostnames from ServiceUri and not from FQDN
- SAM-1756 Dismiss Gridmap usage in ATP
- SAM-1824 Remove FQDN parsing - osg extraction
- SAM-1010 ATP: the service type discovery in the ATP BDII synchronizer should be reviewed
- SAM-1767 Replace 'EGEE' infrastructure with 'EGI'
- SAM-1709 ATP sync script timeout issue
* Tue Aug 17 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.18.4-1%{?dist}
- SAM-1749 - Added UNICORE6 services to ATP
* Tue Aug 15 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.18.4-1%{?dist}
- SAM-1724 - Added new functionality to validate VO feeds xml. The validation is not intrusive and simply prints possible errors.
* Tue Aug 15 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.18.3-1%{?dist}
- SAM-1124 New version to fix SAM-1124 and correction to scheduler jobs creation script
* Tue Aug 9 2011 Pedro Andrade<pedro.andrade@cern.ch> - 1.18.2-1%{?dist}
- SAM-1566 Introduce job clases in the Oracle scheduler jobs - ATP
* Tue Aug 2 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.18.1-1%{?dist}
- SAM-316 ATP: each VO feed is the only authority for VO services mapping
- SAM-1594 ATP: improvement of logging
- SAM-1583 ATP: returns OK while errors are displayed in log file 
- SAM-1603 More restrictions in VO feed xsd file 
- SAM-1654 Error handling while processing vo list from cic portal 
- SAM-1700 Check why mywlcg/gridmap on samval002 shows USCMS-FNAL-WC1 and BNL-ATLAS 
- SAM-1704 gridops domain decommissioning (cic.gridops.org) 
* Mon Jun 29 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.17.2-4%{?dist}
- SAM-1654 Processing wrong status record for vo list from cic portal
* Mon Jun 24 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.17.2-3%{?dist}
- SAM-1640 ATP manually inserts several GOCDB regions
* Mon Jun 20 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.17.2-2%{?dist}
- SAM-1630 atp dependency of egee-NAGIOS
- SAM-1617 Modify atp synchronizer code for federation, tier and site capacities info. as per new GSTAT feeds
* Fri Jun 17 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.17.2-1%{?dist}
- SAM-1239 ATP: bdii synchronizer should also return mappings to 'ce' service type flavour
- SAM-1455 Mark old group entries in VO_feeds as deleted
- SAM-1636 Country information for OSG sites in ATP 
- SAM-1637 ATP - errors while extracting of tier and federation information in /var/log/atp/atp.log
* Fri Jun 10 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.17.1-1%{?dist}
- SAM-1500 ROC 'Italy' present in ACE EGI League
- SAM-1513 Wrong availability and reliability number for few federations in ACE WLCG Tier-2 report
- SAM-1514 Wrong availability and reliability number for federation US-LBNL-ALICE in ACE WLCG Tier-2 report
- SAM-1509 WLCG Tier2 report - wrong numbers for CPUs and HS06.
- SAM-1502 Sites UB_LCG2 and CSC present in ACE WLCG Tier-2 report 
- SAM-1571 ATP: during the synchronizer execution a temporary table is created and/or dropped
- SAM-1559 Improvement to atp_synchro.conf 
- SAM-1440 ATP: regional instances should only store topology of their region
- SAM-1510 Site prague_cesnet_lcg2 is only in ACE WLCG Tier-2 report
- SAM-1503 EGI League - sites from NGI_IE present also as UKI sites
- SAM-1467 ACE is showing (and computing?) availabilities for sites which changed names or migrated services to other site
* Wed May 25 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.9-7%{?dist}
- SAM-1579 ATP synchronizer failing due to change in GOCDB
- SAM-1574 Error - local variable 'lfc_ops_service' referenced before assignment
- SAM-1559 Improvement to atp_synchro.conf 
- SAM-1456 Switch to new Operations portal VO card PI
* Thu May 5 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.9-5%{?dist}
- SAM-1442 Fresh installation of oracle-ATP using nightly validation machine
* Mon May 2 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.9-4%{?dist}
- SAM-1431 Investigate ATP setup on NGI instances
* Fri Apr 29 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.9-3%{?dist}
- SAM-1462 ACE/GridView - downtime start and endtime treated differenty 
* Fri Apr 29 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.9-2%{?dist}
- SAM-1442 Fresh installation of oracle-ATP using nightly validation machine
* Sun Apr 3 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.8-9%{?dist}
- SAM-1376 Errors with updating of MPI services and downtimes in samnag008
* Wed Mar 23 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.8-7%{?dist}
- SAM-1361 ATP - error while extracting KSI2K values from the OIM feed
* Tue Mar 15 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.8-6%{?dist}
- SAM-1124 ATP - OSG downtime creation, modification or deletion (OIM->ATP)
* Tue Mar 8 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.8-4%{?dist}
- SAM-1280 atp - problem with CMS feed
- SAM-1241 ATP: support any group type & group name defined in a VO feed
* Mon Feb 28 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.8-3%{?dist}
- SAM-1309 ATP: DB upgrade to 1.9 - problem when creating from scratch
* Sun Feb 27 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.8-1%{?dist}
- SAM-1233 NDGF-T1 services do not appear in the Tier 1 and federation grouping in ATP
- SAM-1281 ATP: OSG downtimes aren't synchronized in MySQL and Oracle version
- SAM-1154 ATP: OSG downtime IDs are not propagated into the DB
* Fri Feb 11 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.7-3%{?dist}
-SAM-1266 ATP: OSG sites are marked as not certified
* Fri Feb 4 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.7-2%{?dist}
- SAM-1229 ATP: missing VO mappings to services when using servicemap JSON feed 
* Fri Feb 4 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.7-1%{?dist}
- SAM-1229 (ATP: missing VO mappings to services when using servicemap JSON feed
- SAM-1230 Installed capacity information in site_store_cap table is not correct 
* Mon Jan 31 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.6-5%{?dist}
- SAM-1209 ATP - ROC_NAME is null for MPI services 
- SAM-1204 ATP: MPI services are not mapped to any site 
* Tue Jan 25 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.6-4%{?dist}
- SAM -1186 ATP: error in Oracle MPI_SERVICES_UPDATE procedure
- IS-186 modified GSTAT url in atp_synchro.conf
* Fri Jan 21 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.6-3%{?dist}
- SAM-1132 ATP: config_atp incorrectly configures grid-monitoring box
- SAM-1159 Change GOCDB address to goc.egi.eu 
- SAM-1041 ATP: errors updating GOCDB downtimes 
- SAM-1137 ATP: config.logger.error 
* Mon Jan 17 2011 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.6-1%{?dist}
- SAM-1114 ATP: Error in inserting/updating downtimes in atp logs
- SAM-1014 ATP-WEB:ROC name in VO feeds
- SAM-989 ATP: Integrate OPS Tiers information from GStat into ATP
- SAM-988 ATP: Integrate Federations info to generate WLCG reports
- SAM-811 ATP: site_store_cap table should include HSPEC06 numbers instead of KSI2K (or both)
- SAM-413 ATP: automatic groups of MPI services in DB for OPS VO
- SAM-365 ATP: BDII synchronizer should fill CE metadata for MPIs in DB
* Wed Dec 15 2010 Joshi Pradyumna<pjoshi@cern.ch> - 1.16.4-3%{?dist}
- SAM-971:ATP: vo_goup table should have mappings for OPS
* Wed Dec 15 2010 David Collados <dcollado@cern.ch> - 1.16.4-2%{?dist}
- SAM-1047: ATP: db migration scripts from 1.6 to 1.7 in Oracle & Mysql contain servicetype table name instead of service_type
* Tue Dec 14 2010 Joshi Pradyumna <pjoshi@cern.ch> - 1.16.3-1%{?dist}
- SAM-1036: Site entries in SERVICE_GROUP table should to be moved to VO_SERVICE_GROUP table
* Mon Dec 13 2010 David Collados <dcollado@cern.ch> - 1.16.3-1%{?dist}
- SAM-450:  Update list of Service Types and Service Type Flavours
- SAM-1018  ATP: map VOs supporting srmv1 & srmv2 services while reading the BDII to srm service type flavour too
- SAM-1026: atp schema migrate 1.6 to 1.7 in update-08
- SAM-1027: ATP: update spec file to include DB ver 1.7 (currently set to 1.6)
* Fri Dec 10 2010 David Collados <dcollado@cern.ch> - 1.16.2-1%{?dist}
- SAM-961:  ATP: when querying the BDII for service-vo mappings some of the service type flavours used for mappings are wrong and should be updated
- SAM-971:  ATP: vo_goup table should have mappings for OPS
- SAM-984:  atp package should not require MySQL
- SAM-1007: Unique constraint in schema_details table
- SAM-1011: ATP: include srmv2 in the db_mapping_gocdb_bdii_serv_type table in atp config file
- SAM-1017: ATP synchronizer fails to run
* Wed Dec 8 2010 David Collados <dcollado@cern.ch> - 1.16.1-1%{?dist}
- SAM-960:  VOs synchronizer should not delete VOs when they are not anymore in
            the CIC list, but just mark them as 'deleted'
- SAM-996:  improve error output in VO_TOPOLOGY_UPDATE procedure when the service is not found in the DB
- SAM-1003: ATP: remove OPS VO mapping for central-LFCs when synchronizing from GOCDB or OIM
- SAM-1005: VO_TOPOLOGY_UPDATE procedure should not insert/modify groups or
            group_type tables if service is not found in the DB
* Mon Dec 06 2010 James Casey <james.casey@cern.ch> - 1.15.6-5%{?dist}
- Remove Nagios from specfile (SAM-993)
* Mon Dec 06 2010 James Casey <james.casey@cern.ch> - 1.15.6-4%{?dist}
- Remove MySQl dependencies  (SAM-984)
* Mon Nov 29 2010 Joshi Pradyumna <pjoshi@cern.ch> - 1.15.6-3%{?dist}
- SAM-966
* Thu Nov 25 2010 Joshi Pradyumna <pjoshi@cern.ch> - 1.15.5-1%{?dist}
- Bugfixes 
* Mon Oct 25 2010 David Collados <david.collados@cern.ch> - 1.15.4-1%{?dist}
- fixed SAM-875
* Wed Oct 20 2010 David Collados <david.collados@cern.ch> - 1.15.3-1%{?dist}
- atp-web feed fix for SAM-832
- fix to store CPU numbers when no HEPSPEC06 number is passed
* Tue Sep 19 2010 David Collados <david.collados@cern.ch> - 1.15.1-1%{?dist}
- replaced %{name}_django with %{name} under %files web
* Thu Sep 02 2010 James Casey <james.casey@cern.ch> - 1.14.2-2%{?dist}
- dos2unix on atp_synchro.conf to trigger .rpmnew 
* Fri Aug 27 2010 James Casey <james.casey@cern.ch> - 1.14.2-1%{?dist}
- Bugfixes
* Thu Aug 26 2010 James Casey <james.casey@cern.ch> - 1.14.1-1%{?dist}
- Bugfixes
* Wed Aug 25 2010 James Casey <james.casey@cern.ch> - 1.14.0-1%{?dist}
- Repackaging to make it slightly more pythonic
- Added python-django-db-schema for deps
* Tue Aug 24 2010 Joshi Pradyumna <pjoshi@cern.ch> - 1.13-1
- Bug & Features
* Mon Jun 28 2010 James Casey <james.casey@cern.ch> - 1.12-1
- Fixed bugs SITE_UPDATE and SERVICE_UPDATE procedures in ATP MySQL version
* Thu Jun 24 2010 James Casey <james.casey@cern.ch> - 1.11-1
- Fix SAM-576: from_1_2_to_1_3.sql contains VARCHAR2() on mysql not VARCHAR()
* Sun Mar 21 2010 Joshi P S <pjoshi@cern.ch> - 1.10-2
- Modified atp_web directory entries for REST APIs based on django-piston
* Sat Mar 20 2010 David Collados <david.collados@cern.ch> - 1.10-1
- Patch #3931: https://savannah.cern.ch/patch/?3931
- Fixed bug #64538: ATP: Synchronizer_lastrun table is not formalized
- Fixed bug #64542: ATP: schema_details table should go out of ATP
- Fixed bug #64537: ATP: should support GOCDB-4
- Fixed bug #63538: ATP: Missing CE metadata for MPIs in the database
- Fixed bug #63820: ATP: SRM services in GOCDB are not registered in ATP
- Fixed bug #63822: ATP: service last seen is updated even if the transaction failed
- Fixed bug #64163: ATP: add function get_site_name(service_id)
* Tue Mar 09 2010 Jams Casey <james.casey@cern.ch> - 1.9-4
- include 1_2 schemas in bundle
* Mon Mar 08 2010 Jams Casey <james.casey@cern.ch> - 1.9-3
- added 'SRM' flavour to migration scripts(ver_1_1_to_1_2) and ver_1_2 for oracle and mysql db schemas
- Fixed bug #63630: Table 'atp.SERVICE_SITE' doesn't exist
- Fixed bug #63619: ATP Web - JSON site feed does not work
- Fixed bug #63353: Show VO defined site names in VO dowtimes view in ATP web front-end
- Fixed bug #63279: Search VO specific downtimes in ATP by specifying date and time 
- Fixed bug #62824: ATP synchronizer - make infrastructure optional
- Fixed bug #61725: ATP: OSG sites with InteropMonitoring tag set to False are inside the DB is fixed
- Fixed bug #61545: ATP: VO feeds synchronizer should admit empty infrastructure field
- Fixed bug #61453: ATP: request to combine all procedures to synchro VO feeds into single one
- Fixed bug #59245: Downtime search dropdown should not propose "moderate" & "severe"
- Fixed the bug in ATP Downtimes where downtimes were getting stored on the basis of local timestamps instead of UTC timestamps
- added missing 'types' library to serializers.py in ATP web
- modified message for X.509 certificate error
- modified forms.py in ATP-Web to make start and end time fields optional for VO downtime view
- updated to Version 1_2 of DB schema
* Thu Jan 14 2010 David Collados <David.Collados@cern.ch> - 1.8-12
  https://savannah.cern.ch/bugs/?59239
  https://savannah.cern.ch/bugs/?59963
* Wed Jan 13 2010 David Collados <David.Collados@cern.ch> - 1.8-11
  https://savannah.cern.ch/bugs/?59923
* Thu Dec 14 2009 David Collados <David.Collados@cern.ch> - 1.8-3
  https://savannah.cern.ch/bugs/?60463
  https://savannah.cern.ch/bugs/?60608
* Thu Dec 05 2009 David Collados <David.Collados@cern.ch> - 1.8-2
  https://savannah.cern.ch/bugs/?57581
  https://savannah.cern.ch/bugs/?59244
  https://savannah.cern.ch/bugs/?59390
  https://savannah.cern.ch/bugs/?59406
  https://savannah.cern.ch/bugs/?59579
  https://savannah.cern.ch/bugs/?59628
* Tue Nov 10 2009 Steve Traylen <steve.traylen@cern.ch> - 1.8-1
  https://savannah.cern.ch/bugs/?58577
  https://savannah.cern.ch/bugs/?58590
  include synchroLastrun method,
  use a unique topic name.
* Tue Nov 10 2009 Steve Traylen <steve.traylen@cern.ch> - 1.7-1
- Update to version 1.7.
* Wed Oct 21 2009 Steve Traylen <steve.traylen@cern.ch> - 1.6-2
- update to version 1.6
* Wed Oct 21 2009 Steve Traylen <steve.traylen@cern.ch> - 1.5-1
- update to version 1.5
- atp_django.conf renamed as xatp_django.conf to load after wsgi.conf
* Wed Oct 21 2009 Steve Traylen <steve.traylen@cern.ch> - 1.4-1
- New version 1.4
- Add nagios wrapper script.
* Tue Oct 20 2009 Steve Traylen <steve.traylen@cern.ch> - 1.3-1
- New version 1.3 
* Tue Oct 20 2009 Steve Traylen <steve.traylen@cern.ch> - 1.2-1
- New version 1.2 
- Create lib directory as well.
- Add a logrotation configuration.
* Tue Oct 20 2009 Steve Traylen <steve.traylen@cern.ch> - 1.1-3
- Mark the log directory as nagios owned.
- Mark the db configuration file as nagios readable only.
* Tue Oct 20 2009 Steve Traylen <steve.traylen@cern.ch> - 1.1-2
- Allow command to run as user nagios.
* Tue Oct 20 2009 Steve Traylen <steve.traylen@cern.ch> - 1.1-1
- Add new configuration file atp_db.conf
- Require stomppy.
* Mon Oct 19 2009 Steve Traylen <steve.traylen@cern.ch> - 1.0-4
- Move Django and mod_wsgi to only be needed by the -web package
- and not the main package.
- We don't require a mysql server since a remote one would be fine.
* Mon Oct 19 2009 Steve Traylen <steve.traylen@cern.ch> - 1.0-3
- Remove oracle dependencies praying they are only needed on demand.
- Mark configuration files as no replace.
* Tue Oct 13 2009 David Collados <david.collados@cern.ch> - 1.0-2
- Split into atp & atp-web packages
* Mon Sep 14 2009 Steve Traylen <steve.traylen@cern.ch> -  1.0-1
- Initial version.
